package cn.jlsxwkj.common.R;

import cn.jlsxwkj.common.utils.Log;
import cn.jlsxwkj.moudles.logerror.LogError;
import cn.jlsxwkj.moudles.logerror.LogErrorService;
import io.netty.handler.codec.http.HttpResponseStatus;
import jakarta.annotation.Resource;
import org.springframework.web.ErrorResponse;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.RestControllerAdvice;

import java.util.Arrays;

/**
 * @author zh
 */
@RestControllerAdvice
public class GlobalRestExceptionHandler {

    @Resource
    private LogErrorService logErrorService;

    /**
     * 捕捉全局异常
     * @param e 异常
     * @return 封装异常对象
     */
    @ExceptionHandler(Throwable.class)
    public ErrorHandler exception(Exception e) {
        ErrorHandler errorHandler = new ErrorHandler();
        errorHandler.setStatus(HttpResponseStatus.INTERNAL_SERVER_ERROR.code());
        errorHandler.setMessage(HttpResponseStatus.INTERNAL_SERVER_ERROR.reasonPhrase());
        errorHandler.setException(e.getClass().getName());
        if (e instanceof ErrorResponse) {
            errorHandler.setStatus(((ErrorResponse)e).getStatusCode().value());
            errorHandler.setMessage(e.getMessage());
        }
        LogError errorHandlerToLogError = new LogError().castErrorHandlerToLogError(errorHandler);
        errorHandlerToLogError.setErrorInfo(e.getMessage());
        errorHandlerToLogError.setErrorStackTrace(Arrays.toString(e.getStackTrace()));
        logErrorService.insertOne(errorHandlerToLogError);
        Log.error(e.getClass(), "Code       ====> {}", errorHandler.getStatus());
        Log.error(e.getClass(), "Exception  ====> {}", errorHandler.getException());
        Log.error(e.getClass(), "Message    ====> {}", errorHandler.getMessage());
        Log.error(e.getClass(), "ErrInfo    ====> {}", e.getMessage());
        return errorHandler;
    }
}
